@@ -28,16 +28,7 @@
   # initialise
   initTranformers()
 
-  # inform user
-  if (.Platform$OS.type == "windows" &&
-      length(Sys.glob("c:\\cygw*\\bin\\bash.exe"))) {
-    packageStartupMessage(
-      "\nNote: Cygwin seems to be installed on the user's system.\n",
-      "This is no more needed for package ctrdata as of v1.16.0.\n",
-      "Users may chose to delete its folder (look for c:\\cygw*).\n")
-  }
-
   # return
-  invisible()
+  return(invisible(NULL))
 
 } # .onAttach
