@@ -30,6 +30,16 @@ expect_true(
         register = "EUCTR",
         only.count = TRUE)))[["n"]] >= 2L)
 
+# test
+suppressWarnings(
+  suppressMessages(
+    tmp <- ctrLoadQueryIntoDb(
+      queryterm = "2016-004774-17",
+      register = "EUCTR",
+      euctrprotocolsall = FALSE,
+      con = dbc)))
+expect_true(tmp[["n"]] == 1L)
+
 # test
 suppressWarnings(
   suppressMessages(
